ScrollSpeedController typedef
Control the scroll speed if drag over the boundary.
We can pass time here??
timeInMilliSecond is the time passed.
overPercentage is the scroll over the boundary percentage
overSize is the pixel drag over the boundary
itemSize is the drag item size
Maybe you need decide the scroll speed by the given param.
return how many pixels when scroll in 14ms(maybe a frame). 5 is the default
Implementation
typedef ScrollSpeedController = double Function(
int timeInMilliSecond, double overSize, double itemSize);